package p2p

import (
	"context"

	"github.com/gogo/protobuf/proto"
	"github.com/pkg/errors"
)

// Broadcast a message to the p2p network, the message is assumed to be
// broadcasted to the current fork.
func (s *Service) Broadcast(ctx context.Context, msg proto.Message, topic string) error {
	msgBytes, err := proto.Marshal(msg)
	if err != nil {
		return err
	}
	return s.broadcastObject(ctx, msgBytes, topic)
}

// method to broadcast messages to other peers in our gossip mesh.
func (s *Service) broadcastObject(ctx context.Context, obj []byte, topic string) error {
	if err := s.PublishToTopic(ctx, topic, obj); err != nil {
		err := errors.Wrap(err, "could not publish message")
		return err
	}
	return nil
}
